@@ -98,6 +98,11 @@ public:
         return QVariant(QColor::fromHslF(h, s, l, a));
     }
 
+    QVariant fromHsvF(double h, double s, double v, double a) override
+    {
+        return QVariant(QColor::fromHsvF(h, s, v, a));
+    }
+
     QVariant lighter(const QVariant &var, qreal factor)
     {
         QColor color = var.value<QColor>();
@@ -276,7 +281,7 @@ public:
         float matVals[16];
         QV4::ScopedValue v(scope);
         for (quint32 i = 0; i < 16; ++i) {
-            v = array->getIndexed(i);
+            v = array->get(i);
             if (!v->isNumber())
                 return QMatrix4x4();
             matVals[i] = v->asDouble();
